==> vue-code-generator-plugin-test-0.0.2.tgz: package/es/generator/plugins/component/vue3/initState.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createStateContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.state) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            if (!ir.lifeCycles) {
              next.chunks.push({
                type: ChunkType.STRING,
                fileType: cfg.fileType,
                name: VUE_CHUNK_NAME.ScriptVueImp,
                content: "import { ref } from 'vue'",
                linkAfter: [VUE_CHUNK_NAME.ScriptStart]
              });
            }
            createStateContent = function createStateContent() {
              var pieces = [];
              _.forIn(ir.state, function (item, variable) {
                if (item.type === 'JSExpression') {
                  var value = item.value;
                  var _ref = "const " + variable + " = ref(" + value + ");";
                  pieces.push(_ref);
                }
              });
              return pieces.join('\n');
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptInitState,
              content: createStateContent(),
              linkAfter: [VUE_CHUNK_NAME.ScriptVueImp]
            });
            return _context.abrupt("return", next);
          case 8:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref2.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;

==> vue-code-generator-plugin-test-0.0.3.tgz: package/es/generator/plugins/component/vue3/initState.js <==
import _asyncToGenerator from "@babel/runtime/helpers/asyncToGenerator";
import _extends from "@babel/runtime/helpers/extends";
import _regeneratorRuntime from "@babel/runtime/regenerator";
import { ChunkType } from '@alilc/lowcode-code-generator';
import _ from 'lodash';
import { VUE_CHUNK_NAME, linkAfter } from './const';
var pluginFactory = function pluginFactory(config) {
  var cfg = _extends({
    fileType: 'vue'
  }, config);
  var plugin = /*#__PURE__*/function () {
    var _ref2 = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(pre) {
      var next, ir, createStateContent;
      return _regeneratorRuntime.wrap(function _callee$(_context) {
        while (1) switch (_context.prev = _context.next) {
          case 0:
            next = _extends({}, pre);
            ir = next.ir;
            if (ir.state) {
              _context.next = 4;
              break;
            }
            return _context.abrupt("return", next);
          case 4:
            if (!ir.lifeCycles) {
              next.chunks.push({
                type: ChunkType.STRING,
                fileType: cfg.fileType,
                name: VUE_CHUNK_NAME.ScriptVueImp,
                content: "import { ref } from 'vue'",
                linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptVueImp)
              });
            }
            createStateContent = function createStateContent() {
              var pieces = [];
              _.forIn(ir.state, function (item, variable) {
                if (item.type === 'JSExpression') {
                  var value = item.value;
                  var _ref = "const " + variable + " = ref(" + value + ");";
                  pieces.push(_ref);
                }
              });
              return pieces.join('\n');
            };
            next.chunks.push({
              type: ChunkType.STRING,
              fileType: cfg.fileType,
              name: VUE_CHUNK_NAME.ScriptInitState,
              content: createStateContent(),
              linkAfter: linkAfter(VUE_CHUNK_NAME.ScriptInitState)
            });
            return _context.abrupt("return", next);
          case 8:
          case "end":
            return _context.stop();
        }
      }, _callee);
    }));
    return function plugin(_x) {
      return _ref2.apply(this, arguments);
    };
  }();
  return plugin;
};
export default pluginFactory;
